""" This is entry point when using boring from command line"""

from boring.server import Server


def main():
    Server().start()


if __name__ == '__main__':
    # TODO
    pass
